pub fn currency_lookup_error_to_pyvalue_err(e: CurrencyLookupError) -> PyErrExpand description
Converts a currency lookup failure to a Python ValueError.
pub fn currency_lookup_error_to_pyvalue_err(e: CurrencyLookupError) -> PyErrConverts a currency lookup failure to a Python ValueError.